@@ -13,3 +13,11 @@ NULL
 #' @description The data used for calculate the evaluating indicator.
 #'
 NULL
+
+#' @docType data
+#' @name example_meta_data
+#'
+#' @title Example meta data
+#' @description The data contains cells and pseudotime information.
+#'
+NULL
