@@ -4,7 +4,8 @@ template <class T>
 CDL012SquaredHingeSwaps<T>::CDL012SquaredHingeSwaps(const T &Xi,
                                                     const arma::vec &yi,
                                                     const Params<T> &Pi)
-    : CDSwaps<T>(Xi, yi, Pi) {
+    : CDSwaps<T>(Xi, yi, Pi)
+{
   twolambda2 = 2 * this->lambda2;
   qp2lamda2 =
       (LipschitzConst + twolambda2); // this is the univariate lipschitz
@@ -15,14 +16,20 @@ CDL012SquaredHingeSwaps<T>::CDL012SquaredHingeSwaps(const T &Xi,
   lambda1ol = this->lambda1 / qp2lamda2;
 }
 
-template <class T> FitResult<T> CDL012SquaredHingeSwaps<T>::_FitWithBounds() {
+template <class T>
+FitResult<T> CDL012SquaredHingeSwaps<T>::_FitWithBounds()
+{
   throw "This Error should not happen.";
 }
 
-template <class T> FitResult<T> CDL012SquaredHingeSwaps<T>::_Fit() {
+template <class T>
+FitResult<T> CDL012SquaredHingeSwaps<T>::_Fit()
+{
   auto result = CDL012SquaredHinge<T>(*(this->X), this->y, this->P)
-                    .Fit(); // result will be maintained till the end
-  this->b0 = result.b0;     // Initialize from previous later....!
+                    .Fit();
+  // result will be maintained till the end
+  // Initialize from previous later....!
+  this->b0 = result.b0;
   this->B = result.B;
 
   arma::vec onemyxb = result.onemyxb;
@@ -34,13 +41,14 @@ template <class T> FitResult<T> CDL012SquaredHingeSwaps<T>::_Fit() {
   // Fix warning:
   // warning: 'maxindex' may be used uninitialized in this function
   // [-Wmaybe-uninitialized]
-  double Bmaxindex;
+  double Bmaxindex = 0;
 
   this->P.Init = 'u';
 
   bool foundbetter = false;
 
-  for (std::size_t t = 0; t < this->MaxNumSwaps; ++t) {
+  for (std::size_t t = 0; t < this->MaxNumSwaps; ++t)
+  {
     // Rcpp::Rcout << "Swap Number: " << t << "|mean(onemyxb): " <<
     // arma::mean(onemyxb) << "\n";
 
@@ -50,14 +58,17 @@ template <class T> FitResult<T> CDL012SquaredHingeSwaps<T>::_Fit() {
 
     foundbetter = false;
 
-    for (auto &j : NnzIndices) {
+    for (auto &j : NnzIndices)
+    {
 
       arma::vec onemyxbnoj =
           onemyxb + this->B[j] * this->y % matrix_column_get(*(this->X), j);
       arma::uvec indices = arma::find(onemyxbnoj > 0);
 
-      for (std::size_t i = 0; i < this->p; ++i) {
-        if (this->B[i] == 0 && i >= this->NoSelectK) {
+      for (std::size_t i = 0; i < this->p; ++i)
+      {
+        if (this->B[i] == 0 && i >= this->NoSelectK)
+        {
 
           double Biold = 0;
           double Binew;
@@ -68,17 +79,19 @@ template <class T> FitResult<T> CDL012SquaredHingeSwaps<T>::_Fit() {
                            matrix_column_get(*(this->X), i).elem(indices))));
 
           bool converged = false;
-          if (std::abs(partial_i) >= this->lambda1 + stl0Lc) {
+          if (std::abs(partial_i) >= this->lambda1 + stl0Lc)
+          {
 
             // std::cout<<"Adding: "<<i<< std::endl;
             arma::vec onemyxbnoji = onemyxbnoj;
 
-            std::size_t l = 0;
+            // std::size_t l = 0;
             beta_vector Btemp = this->B;
             Btemp[j] = 0;
             // double ObjTemp = Objective(onemyxbnoj,Btemp);
             // double Biolddescent = 0;
-            while (!converged) {
+            while (!converged)
+            {
 
               double x = Biold - partial_i / qp2lamda2;
               double z = std::abs(x) - lambda1ol;
@@ -95,18 +108,20 @@ template <class T> FitResult<T> CDL012SquaredHingeSwaps<T>::_Fit() {
                             (-this->y.elem(indicesi) %
                              matrix_column_get(*(this->X), i).elem(indicesi)));
 
-              if (std::abs((Binew - Biold) / Biold) < 0.0001) {
+              if (std::abs((Binew - Biold) / Biold) < 0.0001)
+              {
                 converged = true;
               }
 
               Biold = Binew;
-              l += 1;
+              // l += 1;
             }
 
             Btemp[i] = Binew;
             double Fnew = Objective(onemyxbnoji, Btemp);
 
-            if (Fnew < Fmin) {
+            if (Fnew < Fmin)
+            {
               Fmin = Fnew;
               maxindex = i;
               Bmaxindex = Binew;
@@ -115,7 +130,8 @@ template <class T> FitResult<T> CDL012SquaredHingeSwaps<T>::_Fit() {
         }
       }
 
-      if (Fmin < this->objective) {
+      if (Fmin < this->objective)
+      {
         this->B[j] = 0;
         this->B[maxindex] = Bmaxindex;
 
@@ -135,12 +151,14 @@ template <class T> FitResult<T> CDL012SquaredHingeSwaps<T>::_Fit() {
         foundbetter = true;
         break;
       }
-      if (foundbetter) {
+      if (foundbetter)
+      {
         break;
       }
     }
 
-    if (!foundbetter) {
+    if (!foundbetter)
+    {
       return result;
     }
   }
